aboutsummaryrefslogtreecommitdiff
path: root/ML_hydro
diff options
context:
space:
mode:
authorErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
committerErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
commitd178c81a0cb1da927bfd7d0bb64043d9484b353b (patch)
tree2a48ab29ef4a72dc1d1ae60e00cd7c0f231ae823 /ML_hydro
parent87fa6dcf3ff19d937313d20cca8f9e2bca1d4aec (diff)
Allow 4 RHS time levels.
Re-generate code.
Diffstat (limited to 'ML_hydro')
-rw-r--r--ML_hydro/configuration.ccl1
-rw-r--r--ML_hydro/schedule.ccl6
-rw-r--r--ML_hydro/src/Boundaries.c34
-rw-r--r--ML_hydro/src/hydro_RHS.c2
-rw-r--r--ML_hydro/src/hydro_con2prim.c2
-rw-r--r--ML_hydro/src/hydro_prim2con.c2
-rw-r--r--ML_hydro/src/hydro_soundWave.c2
-rw-r--r--ML_hydro/src/hydro_vacuum.c2
8 files changed, 26 insertions, 25 deletions
diff --git a/ML_hydro/configuration.ccl b/ML_hydro/configuration.ccl
index 148a1a1..8e2c3c5 100644
--- a/ML_hydro/configuration.ccl
+++ b/ML_hydro/configuration.ccl
@@ -1,3 +1,4 @@
# File produced by Kranc
+REQUIRES GenericFD
REQUIRES LoopControl
diff --git a/ML_hydro/schedule.ccl b/ML_hydro/schedule.ccl
index b145236..0d08eb0 100644
--- a/ML_hydro/schedule.ccl
+++ b/ML_hydro/schedule.ccl
@@ -149,14 +149,14 @@ schedule hydro_RHS IN hydro_evolCalcGroup AFTER hydro_fluxes
SYNC: mom_grouprhs
} "hydro_RHS"
-schedule ML_hydro_ApplyBoundConds in MoL_PostStep
+schedule ML_hydro_SelectBoundConds in MoL_PostStep
{
LANG: C
OPTIONS: level
SYNC: ene_group
SYNC: mass_group
SYNC: mom_group
-} "apply boundary conditions"
+} "select boundary conditions"
schedule ML_hydro_CheckBoundaries at BASEGRID
{
@@ -164,7 +164,7 @@ schedule ML_hydro_CheckBoundaries at BASEGRID
OPTIONS: meta
} "check boundaries treatment"
-schedule group ApplyBCs as ML_hydro_ApplyBCs in MoL_PostStep after ML_hydro_ApplyBoundConds
+schedule group ApplyBCs as ML_hydro_ApplyBCs in MoL_PostStep after ML_hydro_SelectBoundConds
{
# no language specified
} "Apply boundary conditions controlled by thorn Boundary"
diff --git a/ML_hydro/src/hydro_RHS.c b/ML_hydro/src/hydro_RHS.c
index 8629ae3..7260165 100644
--- a/ML_hydro/src/hydro_RHS.c
+++ b/ML_hydro/src/hydro_RHS.c
@@ -87,7 +87,7 @@ void hydro_RHS_Body(cGH const * const cctkGH, CCTK_INT const dir, CCTK_INT const
#pragma omp parallel
LC_LOOP3 (hydro_RHS,
i,j,k, min[0],min[1],min[2], max[0],max[1],max[2],
- cctk_lssh[CCTK_LSSH_IDX(0,0)],cctk_lssh[CCTK_LSSH_IDX(0,1)],cctk_lssh[CCTK_LSSH_IDX(0,2)])
+ cctk_lsh[0],cctk_lsh[1],cctk_lsh[2])
{
int index = INITVALUE;
int subblock_index = INITVALUE;
diff --git a/ML_hydro/src/hydro_con2prim.c b/ML_hydro/src/hydro_con2prim.c
index 2c6fbe0..1ff5e54 100644
--- a/ML_hydro/src/hydro_con2prim.c
+++ b/ML_hydro/src/hydro_con2prim.c
@@ -87,7 +87,7 @@ void hydro_con2prim_Body(cGH const * const cctkGH, CCTK_INT const dir, CCTK_INT
#pragma omp parallel
LC_LOOP3 (hydro_con2prim,
i,j,k, min[0],min[1],min[2], max[0],max[1],max[2],
- cctk_lssh[CCTK_LSSH_IDX(0,0)],cctk_lssh[CCTK_LSSH_IDX(0,1)],cctk_lssh[CCTK_LSSH_IDX(0,2)])
+ cctk_lsh[0],cctk_lsh[1],cctk_lsh[2])
{
int index = INITVALUE;
int subblock_index = INITVALUE;
diff --git a/ML_hydro/src/hydro_prim2con.c b/ML_hydro/src/hydro_prim2con.c
index fabb629..cd1b21f 100644
--- a/ML_hydro/src/hydro_prim2con.c
+++ b/ML_hydro/src/hydro_prim2con.c
@@ -87,7 +87,7 @@ void hydro_prim2con_Body(cGH const * const cctkGH, CCTK_INT const dir, CCTK_INT
#pragma omp parallel
LC_LOOP3 (hydro_prim2con,
i,j,k, min[0],min[1],min[2], max[0],max[1],max[2],
- cctk_lssh[CCTK_LSSH_IDX(0,0)],cctk_lssh[CCTK_LSSH_IDX(0,1)],cctk_lssh[CCTK_LSSH_IDX(0,2)])
+ cctk_lsh[0],cctk_lsh[1],cctk_lsh[2])
{
int index = INITVALUE;
int subblock_index = INITVALUE;
diff --git a/ML_hydro/src/hydro_soundWave.c b/ML_hydro/src/hydro_soundWave.c
index dd2544a..42e986c 100644
--- a/ML_hydro/src/hydro_soundWave.c
+++ b/ML_hydro/src/hydro_soundWave.c
@@ -87,7 +87,7 @@ void hydro_soundWave_Body(cGH const * const cctkGH, CCTK_INT const dir, CCTK_INT
#pragma omp parallel
LC_LOOP3 (hydro_soundWave,
i,j,k, min[0],min[1],min[2], max[0],max[1],max[2],
- cctk_lssh[CCTK_LSSH_IDX(0,0)],cctk_lssh[CCTK_LSSH_IDX(0,1)],cctk_lssh[CCTK_LSSH_IDX(0,2)])
+ cctk_lsh[0],cctk_lsh[1],cctk_lsh[2])
{
int index = INITVALUE;
int subblock_index = INITVALUE;
diff --git a/ML_hydro/src/hydro_vacuum.c b/ML_hydro/src/hydro_vacuum.c
index dd69367..e4ae63a 100644
--- a/ML_hydro/src/hydro_vacuum.c
+++ b/ML_hydro/src/hydro_vacuum.c
@@ -87,7 +87,7 @@ void hydro_vacuum_Body(cGH const * const cctkGH, CCTK_INT const dir, CCTK_INT co
#pragma omp parallel
LC_LOOP3 (hydro_vacuum,
i,j,k, min[0],min[1],min[2], max[0],max[1],max[2],
- cctk_lssh[CCTK_LSSH_IDX(0,0)],cctk_lssh[CCTK_LSSH_IDX(0,1)],cctk_lssh[CCTK_LSSH_IDX(0,2)])
+ cctk_lsh[0],cctk_lsh[1],cctk_lsh[2])
{
int index = INITVALUE;
int subblock_index = INITVALUE;
diff --git a/ML_hydro/src/Boundaries.c b/ML_hydro/src/Boundaries.c
index a274284..49cb164 100644
--- a/ML_hydro/src/Boundaries.c
+++ b/ML_hydro/src/Boundaries.c
@@ -25,7 +25,7 @@ void ML_hydro_CheckBoundaries(CCTK_ARGUMENTS)
return;
}
-void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
+void ML_hydro_SelectBoundConds(CCTK_ARGUMENTS)
{
DECLARE_CCTK_ARGUMENTS;
DECLARE_CCTK_PARAMETERS;
@@ -122,7 +122,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_group_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_ene_group_bound = -1;
if (handle_ene_group_bound < 0) handle_ene_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ene_group_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -141,7 +141,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_group_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_mass_group_bound = -1;
if (handle_mass_group_bound < 0) handle_mass_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mass_group_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -160,7 +160,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom_group_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_mom_group_bound = -1;
if (handle_mom_group_bound < 0) handle_mom_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom_group_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -179,7 +179,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_ene_bound = -1;
if (handle_ene_bound < 0) handle_ene_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ene_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -198,7 +198,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_mass_bound = -1;
if (handle_mass_bound < 0) handle_mass_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mass_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -217,7 +217,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom1_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_mom1_bound = -1;
if (handle_mom1_bound < 0) handle_mom1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom1_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -236,7 +236,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom2_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_mom2_bound = -1;
if (handle_mom2_bound < 0) handle_mom2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom2_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -255,7 +255,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom3_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_mom3_bound = -1;
if (handle_mom3_bound < 0) handle_mom3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom3_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -274,7 +274,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_group_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_ene_group_bound = -1;
if (handle_ene_group_bound < 0) handle_ene_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ene_group_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -291,7 +291,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_group_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_mass_group_bound = -1;
if (handle_mass_group_bound < 0) handle_mass_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mass_group_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -308,7 +308,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom_group_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_mom_group_bound = -1;
if (handle_mom_group_bound < 0) handle_mom_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom_group_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -325,7 +325,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_ene_bound = -1;
if (handle_ene_bound < 0) handle_ene_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ene_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -342,7 +342,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_mass_bound = -1;
if (handle_mass_bound < 0) handle_mass_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mass_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -359,7 +359,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom1_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_mom1_bound = -1;
if (handle_mom1_bound < 0) handle_mom1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom1_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -376,7 +376,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom2_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_mom2_bound = -1;
if (handle_mom2_bound < 0) handle_mom2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom2_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -393,7 +393,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom3_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_mom3_bound = -1;
if (handle_mom3_bound < 0) handle_mom3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_mom3_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -122,7 +122,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_group_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_ene_group_bound = -1;
if (handle_ene_group_bound < 0) handle_ene_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -141,7 +141,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_group_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_mass_group_bound = -1;
if (handle_mass_group_bound < 0) handle_mass_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -160,7 +160,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom_group_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_mom_group_bound = -1;
if (handle_mom_group_bound < 0) handle_mom_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -179,7 +179,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_ene_bound = -1;
if (handle_ene_bound < 0) handle_ene_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -198,7 +198,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_mass_bound = -1;
if (handle_mass_bound < 0) handle_mass_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -217,7 +217,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom1_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_mom1_bound = -1;
if (handle_mom1_bound < 0) handle_mom1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -236,7 +236,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom2_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_mom2_bound = -1;
if (handle_mom2_bound < 0) handle_mom2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -255,7 +255,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom3_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_mom3_bound = -1;
if (handle_mom3_bound < 0) handle_mom3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -274,7 +274,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_group_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_ene_group_bound = -1;
if (handle_ene_group_bound < 0) handle_ene_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -291,7 +291,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_group_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_mass_group_bound = -1;
if (handle_mass_group_bound < 0) handle_mass_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -308,7 +308,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom_group_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_mom_group_bound = -1;
if (handle_mom_group_bound < 0) handle_mom_group_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -325,7 +325,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ene_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_ene_bound = -1;
if (handle_ene_bound < 0) handle_ene_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -342,7 +342,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mass_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_mass_bound = -1;
if (handle_mass_bound < 0) handle_mass_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -359,7 +359,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom1_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_mom1_bound = -1;
if (handle_mom1_bound < 0) handle_mom1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -376,7 +376,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom2_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_mom2_bound = -1;
if (handle_mom2_bound < 0) handle_mom2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -393,7 +393,7 @@ void ML_hydro_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(mom3_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_mom3_bound = -1;
if (handle_mom3_bound < 0) handle_mom3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);